@@ -1,4 +1,6 @@
-package Debug;
+package Farabi::Plugin::Debug;
+
+our $VERSION = '0.25';
 
 # Returns the plugin's name
 sub plugin_name {
